"""Generated by Django 4.0.6 on 2022-07-21 07:11."""

import os
import shutil

from pathlib import Path

from django.db import migrations, models


CONFIG_PATH = Path(os.environ.get("CODEX_CONFIG_DIR", Path.cwd() / "config"))
OLD_COVER_CACHE = CONFIG_PATH / "static"
CACHE_DIR = CONFIG_PATH / "cache"


def remove_old_caches(_apps, _schema_editor):
    """Clean up old cache locations."""
    print("\n  Removing old cover cache...")
    shutil.rmtree(OLD_COVER_CACHE, ignore_errors=True)
    if not CACHE_DIR.is_dir():
        print("  COULD NOT FIND CACHE DIR!")
        return
    print("  Removing old default cache...")
    for path in CACHE_DIR.iterdir():
        if path.suffix == ".djcache":
            path.unlink(missing_ok=True)
        elif str(path).endswith("_timestamp"):
            mtime = path.stat().st_mtime
            new_path = str(path).replace("_timestamp", ".timestamp")
            path = path.replace(new_path)
            os.utime(path, (mtime, mtime))


class Migration(migrations.Migration):
    """Remove old cover_path. LibrarianStatus model. Remove old caches."""

    dependencies = [
        ("codex", "0015_link_comics_to_top_level_folders"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="library",
            name="schema_version",
        ),
        migrations.RemoveField(
            model_name="comic",
            name="cover_path",
        ),
        migrations.CreateModel(
            name="LibrarianStatus",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("type", models.CharField(db_index=True, max_length=64)),
                ("name", models.CharField(db_index=True, max_length=256, null=True)),
                ("complete", models.PositiveSmallIntegerField(default=0)),
                ("total", models.PositiveSmallIntegerField(default=None, null=True)),
                ("active", models.BooleanField(default=False)),
            ],
            options={
                "unique_together": {("type", "name")},
            },
        ),
        migrations.RunPython(remove_old_caches),
    ]
